pub fn parse(path: &Path, file_type: FileType) -> Result<ParsedDocument>Expand description
Read and parse a guidance file according to its detected type.
pub fn parse(path: &Path, file_type: FileType) -> Result<ParsedDocument>Read and parse a guidance file according to its detected type.