Parsers for each supported guidance format.
Modules
- json
- JSON parsing for guidance files that store rules as JSON.
- markdown
- Markdown parsing via
pulldown-cmark. - yaml
- YAML parsing for guidance files that store rules as YAML (e.g. Cursor rules, Windsurf rules).
Structs
- Parsed
Document - A parsed guidance document — the input to the rule engine.
Enums
- Document
Content - Format-specific parsed representation for a document.
Functions
- parse
- Read and parse a guidance file according to its detected type.